==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ElseIfStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.ElseIfStmt;
import io.ciera.tool.sql.ooaofooa.body.ElseIfStmtSet;
import io.ciera.tool.sql.ooaofooa.body.IfStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.IfStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ElseIfStmtSetImpl extends InstanceSet<ElseIfStmtSet,ElseIfStmt> implements ElseIfStmtSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setIf_Statement_ID( UniqueId ref_If_Statement_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setIf_Statement_ID( ref_If_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setBlock_ID( ref_Block_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ElseIfStmt elseifstmt : this ) act_smtset.add( elseifstmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public BlockSet R658_controls_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( ElseIfStmt elseifstmt : this ) blockset.add( elseifstmt.R658_controls_Block() );
        return blockset;
    }
    @Override
    public ValueSet R659_test_result_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ElseIfStmt elseifstmt : this ) valueset.add( elseifstmt.R659_test_result_Value() );
        return valueset;
    }
    @Override
    public IfStmtSet R682_IfStmt() throws XtumlException {
        IfStmtSet ifstmtset = new IfStmtSetImpl();
        for ( ElseIfStmt elseifstmt : this ) ifstmtset.add( elseifstmt.R682_IfStmt() );
        return ifstmtset;
    }
    @Override
    public IfStmtSet R690_IfStmt() throws XtumlException {
        IfStmtSet ifstmtset = new IfStmtSetImpl();
        for ( ElseIfStmt elseifstmt : this ) ifstmtset.add( elseifstmt.R690_IfStmt() );
        return ifstmtset;
    }


    @Override
    public ElseIfStmt nullElement() {
        return ElseIfStmtImpl.EMPTY_ELSEIFSTMT;
    }

    @Override
    public ElseIfStmtSet emptySet() {
      return new ElseIfStmtSetImpl();
    }

    @Override
    public ElseIfStmtSet value() {
        return this;
    }

    @Override
    public List<ElseIfStmt> elements() {
        return Arrays.asList(toArray(new ElseIfStmt[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ElseIfStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.ElseIfStmt;
import io.ciera.tool.sql.ooaofooa.body.ElseIfStmtSet;
import io.ciera.tool.sql.ooaofooa.body.IfStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.IfStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ElseIfStmtSetImpl extends InstanceSet<ElseIfStmtSet,ElseIfStmt> implements ElseIfStmtSet {

    public ElseIfStmtSetImpl() {
    }

    public ElseIfStmtSetImpl(Comparator<? super ElseIfStmt> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setIf_Statement_ID( UniqueId ref_If_Statement_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setIf_Statement_ID( ref_If_Statement_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ElseIfStmt elseifstmt : this ) elseifstmt.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ElseIfStmt elseifstmt : this ) act_smtset.add( elseifstmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public BlockSet R658_controls_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( ElseIfStmt elseifstmt : this ) blockset.add( elseifstmt.R658_controls_Block() );
        return blockset;
    }
    @Override
    public ValueSet R659_test_result_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ElseIfStmt elseifstmt : this ) valueset.add( elseifstmt.R659_test_result_Value() );
        return valueset;
    }
    @Override
    public IfStmtSet R682_IfStmt() throws XtumlException {
        IfStmtSet ifstmtset = new IfStmtSetImpl();
        for ( ElseIfStmt elseifstmt : this ) ifstmtset.add( elseifstmt.R682_IfStmt() );
        return ifstmtset;
    }
    @Override
    public IfStmtSet R690_IfStmt() throws XtumlException {
        IfStmtSet ifstmtset = new IfStmtSetImpl();
        for ( ElseIfStmt elseifstmt : this ) ifstmtset.add( elseifstmt.R690_IfStmt() );
        return ifstmtset;
    }


    @Override
    public ElseIfStmt nullElement() {
        return ElseIfStmtImpl.EMPTY_ELSEIFSTMT;
    }

    @Override
    public ElseIfStmtSet emptySet() {
      return new ElseIfStmtSetImpl();
    }

    @Override
    public ElseIfStmtSet emptySet(Comparator<? super ElseIfStmt> comp) {
      return new ElseIfStmtSetImpl(comp);
    }

    @Override
    public ElseIfStmtSet value() {
        return this;
    }

    @Override
    public List<ElseIfStmt> elements() {
        return Arrays.asList(toArray(new ElseIfStmt[0]));
    }

}
